@@ -17,14 +17,14 @@ use Carp qw(croak);
 use DateTime ();
 use DateTime::HiRes ();
 use DateTime::TimeZone ();
-use List::MoreUtils qw(all any none);
+use List::Util 1.33 qw(all any none);
 use Params::Validate ':all';
 use Scalar::Util qw(blessed);
 use Storable qw(dclone);
 
 use DateTime::Format::Natural::Utils qw(trim);
 
-our $VERSION = '1.16';
+our $VERSION = '1.19';
 
 validation_options(
     on_fail => sub
@@ -142,6 +142,28 @@ sub _init_check
         daytime => {
             type => HASHREF,
             optional => true,
+            callbacks => {
+                'valid daytime' => sub
+                {
+                    my $href = shift;
+                    my %daytimes = map { $_ => true } qw(morning afternoon evening);
+                    if (any { !$daytimes{$_} } keys %$href) {
+                        die "spelling of daytime\n";
+                    }
+                    elsif (any { !defined $href->{$_} } keys %$href) {
+                        die "undefined hour\n";
+                    }
+                    elsif (any { $href->{$_} !~ /^\d{1,2}$/ } keys %$href) {
+                        die "not a valid number\n";
+                    }
+                    elsif (any { $href->{$_} < 0 || $href->{$_} > 23 } keys %$href) {
+                        die "hour out of range\n";
+                    }
+                    else {
+                        return true;
+                    }
+                }
+            },
         },
         datetime => {
             type => OBJECT,
@@ -357,6 +379,8 @@ sub parse_datetime_duration
         $shrinked = true;
     }
 
+    $self->_rewrite_duration(\@date_strings);
+
     $self->_pre_duration(\@date_strings);
     @$self{qw(state truncated_duration)} = ({}, []);
 
@@ -851,7 +875,7 @@ recognized by L<DateTime>. Defaults to 'floating'.
 
 =item * C<daytime>
 
-An anonymous hash reference consisting of customized daytime hours,
+A hash reference consisting of customized daytime hours,
 which may be selectively changed.
 
 =back
@@ -988,6 +1012,7 @@ valuable suggestions and patches:
  Jim Avera
  Olaf Alders
  Karen Etheridge
+ Graham Ollis
 
 =head1 SEE ALSO
 
